<?php
/**
 * The Core Functions for Adventure
 *
 * These core functions are the main feature of the complete.
 *
 * @package Adventure
 * 
 * @since Adventure 1.0
 */
 
ini_set('display_errors','Off');

//CONTENT WIDTH
function complete_content_width() {
	global $content_width;
	$full_width = is_page_template( 'page-fullwidth_template.php' );
	if ( $full_width ) {
		$content_width = 1100;
	}else {
		$content_width = 690;
	}
}
add_action( 'template_redirect', 'complete_content_width' );


//UPDATED: GET THE FIRST IMAGE
function complete_first_image() {
	if(is_404()){
		return;
	}
	global $wp_query;
/*	if( $wp_query->post_count <1){
		return;
	}*/
		global $post, $posts;
		$image_url = '';
		ob_start();
		ob_end_clean();
		if(preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches)){;
		$image_url = $matches [1] [0];
		}
	return $image_url;
}

//complete Site title
if ( ! function_exists( '_wp_render_title_tag' ) ) {
	function complete_wp_title( $title, $sep ) {
		global $paged, $page;
	
		if ( is_feed() )
			return $title;
	
		// Add the site name.
		$title .= get_bloginfo( 'name' );
		$sep ='|';
		// Add the site description for the home/front page.
		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) )
			$title = "$title $sep $site_description";
	
		// Add a page number if necessary.
		if ( $paged >= 2 || $page >= 2 )
			$title = "$title $sep " . sprintf( __( 'Page %s', 'complete' ), max( $paged, $page ) );
	
		return $title;
	}
	add_filter( 'wp_title', 'complete_wp_title', 10, 2 );
}


//Custom Excerpt Length
function complete_excerptlength_teaser($length) {
    return 20;
}
function complete_excerptlength_index($length) {
    return 12;
}
function complete_excerptmore($more) {
    return '.';
}

function complete_excerpt($length_callback='', $more_callback='') {
    if(function_exists($length_callback)){
        add_filter('excerpt_length', $length_callback);
    }
    if(function_exists($more_callback)){
        add_filter('excerpt_more', $more_callback);
    }
    $output = get_the_excerpt();
    $output = apply_filters('wptexturize', $output);
    $output = apply_filters('convert_chars', $output);
    $output = '<p>'.$output.'</p>';
    echo $output;
}

//hex to rgb function
function complete_hex2rgb($hex) {
   $hex = str_replace("#", "", $hex);
 
   if(strlen($hex) == 3) {
      $r = hexdec(substr($hex,0,1).substr($hex,0,1));
      $g = hexdec(substr($hex,1,1).substr($hex,1,1));
      $b = hexdec(substr($hex,2,1).substr($hex,2,1));
   } else {
      $r = hexdec(substr($hex,0,2));
      $g = hexdec(substr($hex,2,2));
      $b = hexdec(substr($hex,4,2));
   }
   $rgb = array($r, $g, $b);
   return implode(",", $rgb); // returns the rgb values separated by commas
   //return $rgb; // returns an array with the rgb values
}

/*complete Color Sanitization*/
function complete_sanitize_hex( $color = '#FFFFFF', $hash = true ) {
		$color = trim( $color );
		$color = str_replace( '#', '', $color );
		if ( 3 == strlen( $color ) ) {
			$color = substr( $color, 0, 1 ) . substr( $color, 0, 1 ) . substr( $color, 1, 1 ) . substr( $color, 1, 1 ) . substr( $color, 2, 1 ) . substr( $color, 2, 1 );
		}

		$substr = array();
		for ( $i = 0; $i <= 5; $i++ ) {
			$default    = ( 0 == $i ) ? 'F' : ( $substr[$i-1] );
			$substr[$i] = substr( $color, $i, 1 );
			$substr[$i] = ( false === $substr[$i] || ! ctype_xdigit( $substr[$i] ) ) ? $default : $substr[$i];
		}
		$hex = implode( '', $substr );

		return ( ! $hash ) ? $hex : '#' . $hex;

}

// allow script & iframe tag within posts
function complete_allow_html( $allowedposttags ){
	global $allowedposttags;
    $allowedposttags['script'] = array(
        'type' => true,
        'src' => true,
        'height' => true,
        'width' => true,
    );
    $allowedposttags['form'] = array(
        'id' => true,
        'class' => true,
        'action' => true,
        'method' => true,
        'name' => true,
        'style' => true,
        'target' => true,
		'novalidate' => true,
    );
    $allowedposttags['input'] = array(
        'id' => true,
        'class' => true,
        'name' => true,
        'style' => true,
        'placeholder' => true,
		'tabindex' => true,
		'type' => true,
		'value' => true,
    );
    $allowedposttags['button'] = array(
        'id' => true,
        'class' => true,
        'name' => true,
        'style' => true,
		'tabindex' => true,
		'type' => true,
		'value' => true,
    );
	

    return $allowedposttags;
}
add_filter('wp_kses_allowed_html','complete_allow_html', 1);

//**Return an ID of an attachment by searching the database with the file URL (Inexpensive query)**//
function complete_attachment_id_by_url( $url ) {
	$parsed_url  = explode( parse_url( WP_CONTENT_URL, PHP_URL_PATH ), $url );

	$this_host = str_ireplace( 'www.', '', parse_url( home_url(), PHP_URL_HOST ) );
	$file_host = str_ireplace( 'www.', '', parse_url( $url, PHP_URL_HOST ) );

	if ( ! isset( $parsed_url[1] ) || empty( $parsed_url[1] ) || ( $this_host != $file_host ) ) {
		return;
	}

	global $wpdb;
	$attachment = $wpdb->get_col( $wpdb->prepare( "SELECT ID FROM {$wpdb->prefix}posts WHERE guid RLIKE %s;", $parsed_url[1] ) );
	return $attachment[0];
}

//Get Image alt from image src
function complete_image_alt( $attachment ) {
	$imgid = complete_attachment_id_by_url($attachment);
	
	if($imgid){
		$imgaltraw = wp_prepare_attachment_for_js($imgid); 
		$imgalt = $imgaltraw['alt'];
		if(!empty($imgalt)){ $imgalt = 'alt="'.$imgaltraw['alt'].'"'; }
		
	}else{
		$imgalt = '';
	}
	
	return $imgalt;
}

// custom post type for Testimonials
function my_custom_post_testimonials() {
	$labels = array(
		'name'               => __( 'Testimonials','complete'),
		'singular_name'      => __( 'Testimonials','complete'),
		'add_new'            => __( 'Add Testimonials','complete'),
		'add_new_item'       => __( 'Add New Testimonial','complete'),
		'edit_item'          => __( 'Edit Testimonial','complete'),
		'new_item'           => __( 'New Testimonial','complete'),
		'all_items'          => __( 'All Testimonials','complete'),
		'view_item'          => __( 'View Testimonial','complete'),
		'search_items'       => __( 'Search Testimonial','complete'),
		'not_found'          => __( 'No Testimonial found','complete'),
		'not_found_in_trash' => __( 'No Testimonial found in the Trash','complete'), 
		'parent_item_colon'  => '',
		'menu_name'          => 'Testimonials'
	);
	$args = array(
		'labels'        => $labels,
		'description'   => 'Manage Testimonials',
		'public'        => true,
		'menu_icon'		=> 'dashicons-format-quote',
		'menu_position' => null,
		'supports'      => array( 'title', 'editor', 'thumbnail'),
		'has_archive'   => true,
		'exclude_from_search' => true,
	);
	register_post_type( 'testimonials', $args );	
}
add_action( 'init', 'my_custom_post_testimonials' );


// add meta box to testimonials
add_action( 'admin_init', 'my_testimonial_admin_function' );
function my_testimonial_admin_function() {
    add_meta_box( 'testimonial_meta_box',
        'Testimonial Info',
        'display_testimonial_meta_box',
        'testimonials', 'normal', 'high'
    );
}
// add meta box form to doctor
function display_testimonial_meta_box( $testimonial ) {
    // Retrieve current name of the Director and Movie Rating based on review ID
	$companyname = esc_html( get_post_meta( $testimonial->ID, 'companyname', true ) );  
    $possition = esc_html( get_post_meta( $testimonial->ID, 'possition', true ) ); 
	
    ?>

<table width="100%">
  <tr>
    <td width="20%">Name </td>
    <td width="80%"><input size="80" type="text" name="companyname" value="<?php echo $companyname; ?>" /></td>
  </tr>
  <tr>
    <td width="20%">Profile </td>
    <td width="80%"><input size="80" type="text" name="possition" value="<?php echo $possition; ?>" /></td>
  </tr>
</table>
<?php    
}
// save testimonial meta box form data
add_action( 'save_post', 'add_testimonial_fields_function', 10, 2 );
function add_testimonial_fields_function( $testimonial_id, $testimonial ) {
    // Check post type for testimonials
    if ( $testimonial->post_type == 'testimonials' ) {
        // Store data in post meta table if present in post data
		if ( isset($_POST['companyname']) ) {
            update_post_meta( $testimonial_id, 'companyname', $_POST['companyname'] );
        } 
        if ( isset($_POST['possition']) ) {
            update_post_meta( $testimonial_id, 'possition', $_POST['possition'] );
        }       
    }
}

//[testimonials-rotator show='-1']
//Testimonials function
function testimonials_rotator_output_func( $atts ){
   extract( shortcode_atts( array(
		'show' => '3',
	), $atts ) );
	  extract( shortcode_atts( array( 'show' => $show,), $atts ) );	
	
	$testimonialoutput = '<div id="testimonials">
  <div class="testimonials">';
	wp_reset_query();
	 $args = array( 'post_type' => 'testimonials', 'posts_per_page' => $show, 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	if ( have_posts() ) :
		while ( have_posts() ) : the_post();
		$companyname = esc_html( get_post_meta( get_the_ID(), 'companyname', true ) );
		$possition = esc_html( get_post_meta( get_the_ID(), 'possition', true ) );
		$testimonialoutput .= '<div class="item">';
		if ( has_post_thumbnail() ){ 
		$testimonialoutput .= '<div class="tm_thumb">'.get_the_post_thumbnail( get_the_ID(), array(70,70) ).'</div>'; 
		}
		$testimonialoutput .= '
		        <div class="tm_description">
				   <p>'.get_the_content().'</p>
				</div>';
				
		$testimonialoutput .= '
		        <div class="tm_info">
					<h3>'.$companyname.'</h3>
					<span>'.$possition.'</span>
				</div>';		
		
		
		$testimonialoutput .= '</div>';
		endwhile;
		 $testimonialoutput .= '</div></div>';
	else:
	  $testimonialoutput = 'Testimonials is empty!';			
	endif;  
	wp_reset_query();
	return $testimonialoutput;
}
add_shortcode( 'testimonials-rotator', 'testimonials_rotator_output_func' );

// Testimonial Box
// [testimonials-box col="3" show="3"]

function testimonials_box_func( $atts ) {
   extract( shortcode_atts( array(
		'col' => '3',
		'show' => '3',
	), $atts ) );
	  extract( shortcode_atts( array( 'show' => $show,), $atts ) ); $tstmnl = ''; wp_reset_query(); 

	$tstmnl = '<div class="testimonialrow">';
	$args = array( 'post_type' => 'testimonials', 'posts_per_page' => $show, 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	$n = 0;
	if ( have_posts() ) {
		while ( have_posts() ) { 
			$n++;
			the_post();
			$companyname = esc_html( get_post_meta( get_the_ID(), 'companyname', true ) );
			$possition = esc_html( get_post_meta( get_the_ID(), 'possition', true ) );
 			
			if( $col == 1 ){
				$tstmnl .= '<div class="tstcols1';
			}elseif( $col == 2 ){
				$tstmnl .= '<div class="tstcols2';
			}elseif( $col == 3 ){
				$tstmnl .= '<div class="tstcols3';
			}elseif( $col == 4 ){
				$tstmnl .= '<div class="tstcols4';
			}
				$tstmnl .= '">';
				
                $tstmnl .= '<div class="testimonial-box"> 
				     <div class="tm_thumb">'.get_the_post_thumbnail( get_the_ID(), array(125,125) ).'</div>
					 <em>'.get_the_content().'</em>
                     </div>
                     <div class="testimonial-inforarea">
					 <p>'.$companyname.'</p>
					<span>'.$possition.'</span>
                     </div>
				';
                $tstmnl .= '</div>
				';
		}
	}else{
		$tstmnl .= 'Sorry No Team Found.';
	}
	wp_reset_query();
	$tstmnl .= '</div>';
    return $tstmnl;
}
add_shortcode( 'testimonials-box', 'testimonials_box_func' );
//

//custom post type for Our Team
function my_custom_post_team() {
	$labels = array(
		'name'               => __( 'Our Team', 'complete' ),
		'singular_name'      => __( 'Our Team', 'complete' ),
		'add_new'            => __( 'Add New', 'complete' ),
		'add_new_item'       => __( 'Add New Team Member', 'complete' ),
		'edit_item'          => __( 'Edit Team Member', 'complete' ),
		'new_item'           => __( 'New Member', 'complete' ),
		'all_items'          => __( 'All Members', 'complete' ),
		'view_item'          => __( 'View Members', 'complete' ),
		'search_items'       => __( 'Search Team Members', 'complete' ),
		'not_found'          => __( 'No Team members found', 'complete' ),
		'not_found_in_trash' => __( 'No Team members found in the Trash', 'complete' ), 
		'parent_item_colon'  => '',
		'menu_name'          => 'Our Team'
	);
	$args = array(
		'labels'        => $labels,
		'description'   => 'Manage Team',
		'public'        => true,
		'menu_position' => null,
		'menu_icon'		=> 'dashicons-groups',
		'supports'      => array( 'title', 'editor', 'thumbnail' ),
		'rewrite' => array('slug' => 'our-guide'),
		'has_archive'   => true,
		'exclude_from_search' => true,
	);
	register_post_type( 'team', $args );
}
add_action( 'init', 'my_custom_post_team' );

// add meta box to team
add_action( 'admin_init', 'my_team_admin_function' );
function my_team_admin_function() {
    add_meta_box( 'team_meta_box',
        'Member Info',
        'display_team_meta_box',
        'team', 'normal', 'high'
    );
}
// add meta box form to team
function display_team_meta_box( $team ) {
    // Retrieve current name of the Director and Movie Rating based on review ID
    $designation = esc_html( get_post_meta( $team->ID, 'designation', true ) );
    $member_email = esc_html( get_post_meta( $team->ID, 'member_email', true ) );
	
    $facebook = get_post_meta( $team->ID, 'facebook', true );
	$facebooklink = esc_url( get_post_meta( $team->ID, 'facebooklink', true ) );

    $twitter = get_post_meta( $team->ID, 'twitter', true );
	$twitterlink = esc_url( get_post_meta( $team->ID, 'twitterlink', true ) );

	$instagram = get_post_meta( $team->ID, 'instagram', true );
	$instagramlink = esc_url( get_post_meta( $team->ID, 'instagramlink', true ) );	

    $linkedin = get_post_meta( $team->ID, 'linkedin', true );
	$linkedinlink = esc_url( get_post_meta( $team->ID, 'linkedinlink', true ) );

    $pinterest = get_post_meta( $team->ID, 'pinterest', true );
	$pinterestlink = get_post_meta( $team->ID, 'pinterestlink', true );
	
	$app_button_text = esc_html( get_post_meta( $team->ID, 'app_button_text', true ) );
	$app_button_link = esc_url( get_post_meta( $team->ID, 'app_button_link', true ) );
    ?>
    <table width="100%">
        <tr>
            <td width="20%">Designation </td>
            <td width="80%"><input type="text" name="designation" value="<?php echo $designation; ?>" /></td>
        </tr>
        <tr>
            <td width="20%">Email Address </td>
            <td width="80%"><input type="text" name="member_email" value="<?php echo $member_email; ?>" /></td>
        </tr>
        <tr>
            <td width="20%">Appointment Button Text</td>
            <td width="80%"><input type="text" name="app_button_text" value="<?php echo $app_button_text; ?>" /></td>
        </tr>
        <tr>
            <td width="20%">Appointment Button Link</td>
            <td width="80%"><input type="text" name="app_button_link" value="<?php echo $app_button_link; ?>" /></td>
        </tr>
        <tr>
        	<td width="20%">&nbsp;</td>
            <td width="40%" style="padding:10px 0 5px 0;"><strong>Icon Name Eg: facebook</strong></td>
            <td width="40%" style="padding:10px 0 5px 0;"><strong>Social Link Eg: http://www.facebook.com/xyz</strong></td>
        </tr>        
        <tr>
            <td width="20%">Social link 1</td>
            <td width="40%"><input type="text" name="facebook" value="<?php echo $facebook; ?>" /></td>
            <td width="40%"><input style="width:500px;" type="text" name="facebooklink" value="<?php echo $facebooklink; ?>" /></td>
        </tr>
        <tr>
            <td width="20%">Social Link 2</td>
            <td width="40%"><input type="text" name="twitter" value="<?php echo $twitter; ?>" /></td>
            <td width="40%"><input style="width:500px;" type="text" name="twitterlink" value="<?php echo $twitterlink; ?>" /></td>
        </tr>
        <tr>
            <td width="20%">Social Link 3</td>
            <td width="40%"><input type="text" name="instagram" value="<?php echo $instagram; ?>" /></td>
            <td width="40%"><input style="width:500px;" type="text" name="instagramlink" value="<?php echo $instagramlink; ?>" /></td>
        </tr>
        <tr>
            <td width="20%">Social Link 4</td>
            <td width="40%"><input type="text" name="linkedin" value="<?php echo $linkedin; ?>" /></td>
            <td width="40%"><input style="width:500px;" type="text" name="linkedinlink" value="<?php echo $linkedinlink; ?>" /></td>
        </tr>        
        <tr>
            <td width="20%">Social Link 5</td>
            <td width="40%"><input type="text" name="pinterest" value="<?php echo $pinterest; ?>" /></td>
            <td width="40%"><input style="width:500px;" type="text" name="pinterestlink" value="<?php echo $pinterestlink; ?>" /></td>
        </tr>
        <tr>
        	<td width="100%" colspan="3"><label style="font-size:12px;"><strong>Note:</strong> Icon name should be in lowercase without space. More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/</label> </td>
        </tr>
    </table>
    <?php    
}
// save team meta box form data
add_action( 'save_post', 'add_team_fields_function', 10, 2 );
function add_team_fields_function( $team_id, $team ) {
    // Check post type for testimonials
    if ( $team->post_type == 'team' ) {
        // Store data in post meta table if present in post data
        if ( isset($_POST['designation']) ) {
            update_post_meta( $team_id, 'designation', $_POST['designation'] );
        }
		 if ( isset($_POST['member_email']) ) {
            update_post_meta( $team_id, 'member_email', $_POST['member_email'] );
        }
        if ( isset($_POST['facebook']) ) {
            update_post_meta( $team_id, 'facebook', $_POST['facebook'] );
        }
		if ( isset($_POST['facebooklink']) ) {
            update_post_meta( $team_id, 'facebooklink', $_POST['facebooklink'] );
        }
        if ( isset($_POST['twitter']) ) {
            update_post_meta( $team_id, 'twitter', $_POST['twitter'] );
        }
		if ( isset($_POST['twitterlink']) ) {
            update_post_meta( $team_id, 'twitterlink', $_POST['twitterlink'] );
        }
        if ( isset($_POST['instagram']) ) {
            update_post_meta( $team_id, 'instagram', $_POST['instagram'] );
        }
		if ( isset($_POST['instagramlink']) ) {
            update_post_meta( $team_id, 'instagramlink', $_POST['instagramlink'] );
        }		
        if ( isset($_POST['linkedin']) ) {
            update_post_meta( $team_id, 'linkedin', $_POST['linkedin'] );
        }
		if ( isset($_POST['linkedinlink']) ) {
            update_post_meta( $team_id, 'linkedinlink', $_POST['linkedinlink'] );
        }
		if ( isset($_POST['pinterest']) ) {
            update_post_meta( $team_id, 'pinterest', $_POST['pinterest'] );
        }
		if ( isset($_POST['pinterestlink']) ) {
            update_post_meta( $team_id, 'pinterestlink', $_POST['pinterestlink'] );
        }
		if ( isset($_POST['app_button_text']) ) {
            update_post_meta( $team_id, 'app_button_text', $_POST['app_button_text'] );
        }
		if ( isset($_POST['app_button_link']) ) {
            update_post_meta( $team_id, 'app_button_link', $_POST['app_button_link'] );
        }
    }
}

// Shortcode Our Team
// [ourteam col="4" show="4" excerptlength="25"]

function ourteam_func( $atts ) {
   extract( shortcode_atts( array(
		'col' => '',
		'show' => '',
		'excerptlength' => '',
		'viewalltext' => '',
		'url' => '',
	), $atts ) );
	  extract( shortcode_atts( array( 'show' => $show,), $atts ) ); $ourtm = ''; wp_reset_query(); 

	$ourtm = '<div class="sectionrow team-wrap">';
	$args = array( 'post_type' => 'team', 'posts_per_page' => $show, 'post__not_in' => get_option('sticky_posts'), 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	$n = 0;
	if ( have_posts() ) {
		while ( have_posts() ) { 
			$n++;
			the_post();
			$designation = esc_html( get_post_meta( get_the_ID(), 'designation', true ) );
			
			$facebook = get_post_meta( get_the_ID(), 'facebook', true );
			$facebooklink = get_post_meta( get_the_ID(), 'facebooklink', true );
			
			$twitter = get_post_meta( get_the_ID(), 'twitter', true );
			$twitterlink = get_post_meta( get_the_ID(), 'twitterlink', true );
			
			$instagram = get_post_meta( get_the_ID(), 'instagram', true );
			$instagramlink = get_post_meta( get_the_ID(), 'instagramlink', true );
			
			$googleplus = get_post_meta( get_the_ID(), 'googleplus', true );
			$googlepluslink = get_post_meta( get_the_ID(), 'googlepluslink', true );
			
			$linkedin = get_post_meta( get_the_ID(), 'linkedin', true );
			$linkedinlink = get_post_meta( get_the_ID(), 'linkedinlink', true );
			
			$pinterest = get_post_meta( get_the_ID(), 'pinterest', true );
			$pinterestlink = get_post_meta( get_the_ID(), 'pinterestlink', true );			

			if( $col == 1 ){
				$ourtm .= '<div class="cols1';
			}elseif( $col == 2 ){
				$ourtm .= '<div class="cols2';
			}elseif( $col == 3 ){
				$ourtm .= '<div class="cols3';
			}elseif( $col == 4 ){
				$ourtm .= '<div class="cols4';
			}elseif( $col == 5 ){
				$ourtm .= '<div class="cols5';
			}
			$ourtm .= '">';
 
			$ourtm .= ' 
			<div class="team-thumb">
			<a href="'.get_permalink().'" title="'.get_the_title().'">'.( (get_the_post_thumbnail( get_the_ID(), 'full') != '') ? get_the_post_thumbnail( get_the_ID(), 'full') : '<img src="'.get_template_directory_uri().'/images/team_thumb.jpg" />' ).'</a></div>';
                $ourtm .= '<div class="team-infobox">
                	
					<h5><a href="'.get_permalink().'">'.get_the_title().'</a></h5>';					
					if( $designation != '' ){ $ourtm .= '<span>'.$designation.'</span>';}
					
                    $ourtm .= ' '.( ($excerptlength!='') ? '<p>'.wp_trim_words( get_the_content(), $excerptlength, '' ).'</p>' : '' ).'';
 						$ourtm .= '<div class="social-icons team-socials">';
						if( $facebook != '' ){
                    	$ourtm .= '<a href="'.$facebooklink.'" title="'.$facebook.'" target="_blank"><i class="fa fa-'.$facebook.' fa-lg"></i></a>';
						}
						if( $twitter != '' ){
                    	$ourtm .= '<a href="'.$twitterlink.'" title="'.$twitter.'" target="_blank"><i class="fa fa-'.$twitter.' fa-lg"></i></a>';
						}
						if( $instagram != '' ){
                    	$ourtm .= '<a href="'.$instagramlink.'" title="'.$instagram.'" target="_blank"><i class="fa fa-'.$instagram.' fa-lg"></i></a>';
						}
						if( $googleplus != '' ){
                    	$ourtm .= '<a href="'.$googlepluslink.'" title="'.$googleplus.'" target="_blank"><i class="fa fa-'.$googleplus.' fa-lg"></i></a>';
						}						
						if( $linkedin != '' ){
                    	$ourtm .= '<a href="'.$linkedinlink.'" title="'.$linkedin.'" target="_blank"><i class="fa fa-'.$linkedin.' fa-lg"></i></a>';
						}
						if( $pinterest != '' ){
                    	$ourtm .= '<a href="'.$pinterestlink.'" title="'.$pinterest.'" target="_blank"><i class="fa fa-'.$pinterest.' fa-lg"></i></a>';
						}
                $ourtm .= '</div></div>
				</div>';
		}
	}else{
		$ourtm .= 'Sorry, No Team Member Found.';
	}
	wp_reset_query();
	$ourtm .= '</div>';
    return $ourtm;
}
add_shortcode( 'ourteam', 'ourteam_func' );
// Shortcode Our Team Inner
// [ourteaminner col="4" show="4"]

function ourteaminner_func( $atts ) {
   extract( shortcode_atts( array(
		'col' => '',
		'show' => '',
		'viewalltext' => '',
		'url' => '',
	), $atts ) );
	  extract( shortcode_atts( array( 'show' => $show,), $atts ) ); $ourtm = ''; 
	  wp_reset_query(); 

	$ourtm = '<div class="sectionrow team-inner">';
	$args = array( 'post_type' => 'team', 'posts_per_page' => $show, 'post__not_in' => get_option('sticky_posts'), 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	$n = 0;
	if ( have_posts() ) {
		while ( have_posts() ) { 
			$n++;
			the_post();
			$designation = esc_html( get_post_meta( get_the_ID(), 'designation', true ) );
			
			$facebook = get_post_meta( get_the_ID(), 'facebook', true );
			$facebooklink = get_post_meta( get_the_ID(), 'facebooklink', true );
			
			$twitter = get_post_meta( get_the_ID(), 'twitter', true );
			$twitterlink = get_post_meta( get_the_ID(), 'twitterlink', true );
			
			$instagram = get_post_meta( get_the_ID(), 'instagram', true );
			$instagramlink = get_post_meta( get_the_ID(), 'instagramlink', true );
			
			$googleplus = get_post_meta( get_the_ID(), 'googleplus', true );
			$googlepluslink = get_post_meta( get_the_ID(), 'googlepluslink', true );
			
			$linkedin = get_post_meta( get_the_ID(), 'linkedin', true );
			$linkedinlink = get_post_meta( get_the_ID(), 'linkedinlink', true );
			
			$pinterest = get_post_meta( get_the_ID(), 'pinterest', true );
			$pinterestlink = get_post_meta( get_the_ID(), 'pinterestlink', true );			

			if( $col == 1 ){
				$ourtm .= '<div class="cols1';
			}elseif( $col == 2 ){
				$ourtm .= '<div class="cols2';
			}elseif( $col == 3 ){
				$ourtm .= '<div class="cols3';
			}elseif( $col == 4 ){
				$ourtm .= '<div class="cols4';
			}elseif( $col == 5 ){
				$ourtm .= '<div class="cols5';
			}
			$ourtm .= '">';
 
			$ourtm .= ' 
			<div class="team-thumb">
			<a href="'.get_permalink().'" title="'.get_the_title().'">'.( (get_the_post_thumbnail( get_the_ID(), 'full') != '') ? get_the_post_thumbnail( get_the_ID(), 'full') : '<img src="'.get_template_directory_uri().'/images/team_thumb.jpg" />' ).'</a></div>';
                $ourtm .= '<div class="team-infobox">
                	
					<h5><a href="'.get_permalink().'">'.get_the_title().'</a></h5>';					
					if( $designation != '' ){ $ourtm .= '<span>'.$designation.'</span>';}
					
 						$ourtm .= '<div class="social-icons">';
						if( $facebook != '' ){
                    	$ourtm .= '<a href="'.$facebooklink.'" title="'.$facebook.'" target="_blank"><i class="fa fa-'.$facebook.' fa-lg"></i></a>';
						}
						if( $twitter != '' ){
                    	$ourtm .= '<a href="'.$twitterlink.'" title="'.$twitter.'" target="_blank"><i class="fa fa-'.$twitter.' fa-lg"></i></a>';
						}
						if( $instagram != '' ){
                    	$ourtm .= '<a href="'.$instagramlink.'" title="'.$instagram.'" target="_blank"><i class="fa fa-'.$instagram.' fa-lg"></i></a>';
						}
						if( $googleplus != '' ){
                    	$ourtm .= '<a href="'.$googlepluslink.'" title="'.$googleplus.'" target="_blank"><i class="fa fa-'.$googleplus.' fa-lg"></i></a>';
						}						
						if( $linkedin != '' ){
                    	$ourtm .= '<a href="'.$linkedinlink.'" title="'.$linkedin.'" target="_blank"><i class="fa fa-'.$linkedin.' fa-lg"></i></a>';
						}
						if( $pinterest != '' ){
                    	$ourtm .= '<a href="'.$pinterestlink.'" title="'.$pinterest.'" target="_blank"><i class="fa fa-'.$pinterest.' fa-lg"></i></a>';
						}
                $ourtm .= '</div></div>
				</div>';
		}
	}else{
		$ourtm .= 'Sorry, No Team Member Found.';
	}
	wp_reset_query();
	$ourtm .= '</div>';
    return $ourtm;
}
add_shortcode( 'ourteaminner', 'ourteaminner_func' );

// Register Custom Post Type
// Register Custom Post Type Tours
function custom_post_type_tours() {

	$labels = array(
		'name'                  => _x( 'Tours', 'Post Type General Name', 'complete' ),
		'singular_name'         => _x( 'Tour', 'Post Type Singular Name', 'complete' ),
		'menu_name'             => __( 'Tours', 'complete' ),
		'name_admin_bar'        => __( 'Tour', 'complete' ),
		'archives'              => __( 'Item Archives', 'complete' ),
		'attributes'            => __( 'Item Attributes', 'complete' ),
		'parent_item_colon'     => __( 'Parent Item:', 'complete' ),
		'all_items'             => __( 'All Items', 'complete' ),
		'add_new_item'          => __( 'Add New Item', 'complete' ),
		'add_new'               => __( 'Add New', 'complete' ),
		'new_item'              => __( 'New Item', 'complete' ),
		'edit_item'             => __( 'Edit Item', 'complete' ),
		'update_item'           => __( 'Update Item', 'complete' ),
		'view_item'             => __( 'View Item', 'complete' ),
		'view_items'            => __( 'View Items', 'complete' ),
		'search_items'          => __( 'Search Item', 'complete' ),
		'not_found'             => __( 'Not found', 'complete' ),
		'not_found_in_trash'    => __( 'Not found in Trash', 'complete' ),
		'featured_image'        => __( 'Featured Image', 'complete' ),
		'set_featured_image'    => __( 'Set featured image', 'complete' ),
		'remove_featured_image' => __( 'Remove featured image', 'complete' ),
		'use_featured_image'    => __( 'Use as featured image', 'complete' ),
		'insert_into_item'      => __( 'Insert into item', 'complete' ),
		'uploaded_to_this_item' => __( 'Uploaded to this item', 'complete' ),
		'items_list'            => __( 'Items list', 'complete' ),
		'items_list_navigation' => __( 'Items list navigation', 'complete' ),
		'filter_items_list'     => __( 'Filter items list', 'complete' ),
	);
	$rewrite = array(
		'slug'                  => 'tour',
		'with_front'            => true,
		'pages'                 => true,
		'feeds'                 => true,
	);
	$args = array(
		'label'                 => __( 'Tour', 'complete' ),
		'description'           => __( 'Post type created for tours.', 'complete' ),
		'labels'                => $labels,
		'supports'              => array( 'title', 'editor', 'thumbnail' ),
		'hierarchical'          => false,
		'public'                => true,
		'show_ui'               => true,
		'show_in_menu'          => true,
		'menu_position'         => 25,
		'menu_icon'             => 'dashicons-palmtree',
		'show_in_admin_bar'     => true,
		'show_in_nav_menus'     => true,
		'can_export'            => true,
		'has_archive'           => true,
		'exclude_from_search'   => false,
		'publicly_queryable'    => true,
		'rewrite'               => $rewrite,
		'capability_type'       => 'page',
	);
	register_post_type( 'skt_tours', $args );

}
add_action( 'init', 'custom_post_type_tours', 0 );

// add meta box to tour
add_action( 'admin_init', 'my_tour_admin_function' );
function my_tour_admin_function() {
    add_meta_box( 'tour_meta_box',
        'Tour Info',
        'display_tour_meta_box',
        'skt_tours', 'normal', 'high'
    );
}
// add meta box form to tour
function display_tour_meta_box( $skt_tours ) {
    // Retrieve current name of the Tour based on review ID
	$tourexcerpt = esc_html( get_post_meta( $skt_tours->ID, 'tourexcerpt', true ) );
    $tourdays = esc_html( get_post_meta( $skt_tours->ID, 'tourdays', true ) );
    $tourprice = esc_html( get_post_meta( $skt_tours->ID, 'tourprice', true ) );
    ?>
    <table width="100%">
        <tr>
            <td width="20%">Short Description </td>
            <td width="80%"><textarea cols="50" rows="4" type="text" name="tourexcerpt"><?php echo $tourexcerpt; ?></textarea></td>
        </tr>
        <tr>
            <td width="20%">Number of Days </td>
            <td width="80%"><input type="text" name="tourdays" value="<?php echo $tourdays; ?>" /></td>
        </tr>
        <tr>
            <td width="20%">Price </td>
            <td width="80%"><input type="text" name="tourprice" value="<?php echo $tourprice; ?>" /></td>
        </tr>
    </table>
    <?php    
}
// save tour meta box form data
add_action( 'save_post', 'add_tour_fields_function', 10, 2 );
function add_tour_fields_function( $tour_id, $skt_tours ) {
    // Check post type for tour
    if ( $skt_tours->post_type == 'skt_tours' ) {
        // Store data in post meta table if present in post data
		if ( isset($_POST['tourexcerpt']) ) {
            update_post_meta( $tour_id, 'tourexcerpt', $_POST['tourexcerpt'] );
        }
        if ( isset($_POST['tourdays']) ) {
            update_post_meta( $tour_id, 'tourdays', $_POST['tourdays'] );
        }
		 if ( isset($_POST['tourprice']) ) {
            update_post_meta( $tour_id, 'tourprice', $_POST['tourprice'] );
        }
    }
}

// Register Custom Taxonomy Tours Category
function custom_taxonomy_tours_category() {

	$labels = array(
		'name'                       => _x( 'Categories', 'Taxonomy General Name', 'complete' ),
		'singular_name'              => _x( 'Category', 'Taxonomy Singular Name', 'complete' ),
		'menu_name'                  => __( 'Categories', 'complete' ),
		'all_items'                  => __( 'All Items', 'complete' ),
		'parent_item'                => __( 'Parent Item', 'complete' ),
		'parent_item_colon'          => __( 'Parent Item:', 'complete' ),
		'new_item_name'              => __( 'New Item Name', 'complete' ),
		'add_new_item'               => __( 'Add New Item', 'complete' ),
		'edit_item'                  => __( 'Edit Item', 'complete' ),
		'update_item'                => __( 'Update Item', 'complete' ),
		'view_item'                  => __( 'View Item', 'complete' ),
		'separate_items_with_commas' => __( 'Separate items with commas', 'complete' ),
		'add_or_remove_items'        => __( 'Add or remove items', 'complete' ),
		'choose_from_most_used'      => __( 'Choose from the most used', 'complete' ),
		'popular_items'              => __( 'Popular Items', 'complete' ),
		'search_items'               => __( 'Search Items', 'complete' ),
		'not_found'                  => __( 'Not Found', 'complete' ),
		'no_terms'                   => __( 'No items', 'complete' ),
		'items_list'                 => __( 'Items list', 'complete' ),
		'items_list_navigation'      => __( 'Items list navigation', 'complete' ),
	);
	$rewrite = array(
		'slug'                       => 'tours-category',
		'with_front'                 => true,
		'hierarchical'               => false,
	);
	$args = array(
		'labels'                     => $labels,
		'hierarchical'               => true,
		'public'                     => true,
		'show_ui'                    => true,
		'show_admin_column'          => true,
		'show_in_nav_menus'          => true,
		'show_tagcloud'              => false,
		'rewrite'                    => $rewrite,
	);
	register_taxonomy( 'skt_tours_category', array( 'skt_tours' ), $args );

}
add_action( 'init', 'custom_taxonomy_tours_category', 0 );

if( ! class_exists( 'Showcase_skt_tours_category' ) ) {
  class Showcase_skt_tours_category {
    
    public function __construct() {
     //
    }

    /**
     * Initialize the class and start calling our hooks and filters
     */
     public function init() {
     // Image actions
     add_action( 'skt_tours_category_add_form_fields', array( $this, 'add_category_image' ), 10, 2 );
     add_action( 'created_skt_tours_category', array( $this, 'save_category_image' ), 10, 2 );
     add_action( 'skt_tours_category_edit_form_fields', array( $this, 'update_category_image' ), 10, 2 );
     add_action( 'edited_skt_tours_category', array( $this, 'updated_category_image' ), 10, 2 );
     add_action( 'admin_enqueue_scripts', array( $this, 'load_media' ) );
     add_action( 'admin_footer', array( $this, 'add_script' ) );
   }

   public function load_media() {
     if( ! isset( $_GET['taxonomy'] ) || $_GET['taxonomy'] != 'skt_tours_category' ) {
       return;
     }
     wp_enqueue_media();
   }
  
   /**
    * Add a form field in the new category page
    * @since 1.0.0
    */
  
   public function add_category_image( $taxonomy ) { ?>
     <div class="form-field term-group">
       <label for="showcase-taxonomy-image-id"><?php _e( 'Image', 'showcase' ); ?></label>
       <input type="hidden" id="showcase-taxonomy-image-id" name="showcase-taxonomy-image-id" class="custom_media_url" value="">
       <div id="category-image-wrapper"></div>
       <p>
         <input type="button" class="button button-secondary showcase_tax_media_button" id="showcase_tax_media_button" name="showcase_tax_media_button" value="<?php _e( 'Add Image', 'showcase' ); ?>" />
         <input type="button" class="button button-secondary showcase_tax_media_remove" id="showcase_tax_media_remove" name="showcase_tax_media_remove" value="<?php _e( 'Remove Image', 'showcase' ); ?>" />
       </p>
     </div>
   <?php }

   /**
    * Save the form field
    * @since 1.0.0
    */
   public function save_category_image( $term_id, $tt_id ) {
     if( isset( $_POST['showcase-taxonomy-image-id'] ) && '' !== $_POST['showcase-taxonomy-image-id'] ){
       add_term_meta( $term_id, 'showcase-taxonomy-image-id', absint( $_POST['showcase-taxonomy-image-id'] ), true );
     }
    }

    /**
     * Edit the form field
     * @since 1.0.0
     */
    public function update_category_image( $term, $taxonomy ) { ?>
      <tr class="form-field term-group-wrap">
        <th scope="row">
          <label for="showcase-taxonomy-image-id"><?php _e( 'Image', 'showcase' ); ?></label>
        </th>
        <td>
          <?php $image_id = get_term_meta( $term->term_id, 'showcase-taxonomy-image-id', true ); ?>
          <input type="hidden" id="showcase-taxonomy-image-id" name="showcase-taxonomy-image-id" value="<?php echo esc_attr( $image_id ); ?>">
          <div id="category-image-wrapper">
            <?php if( $image_id ) { ?>
              <?php echo wp_get_attachment_image( $image_id, 'thumbnail' ); ?>
            <?php } ?>
          </div>
          <p>
            <input type="button" class="button button-secondary showcase_tax_media_button" id="showcase_tax_media_button" name="showcase_tax_media_button" value="<?php _e( 'Add Image', 'showcase' ); ?>" />
            <input type="button" class="button button-secondary showcase_tax_media_remove" id="showcase_tax_media_remove" name="showcase_tax_media_remove" value="<?php _e( 'Remove Image', 'showcase' ); ?>" />
          </p>
        </td>
      </tr>
   <?php }

   /**
    * Update the form field value
    * @since 1.0.0
    */
   public function updated_category_image( $term_id, $tt_id ) {
     if( isset( $_POST['showcase-taxonomy-image-id'] ) && '' !== $_POST['showcase-taxonomy-image-id'] ){
       update_term_meta( $term_id, 'showcase-taxonomy-image-id', absint( $_POST['showcase-taxonomy-image-id'] ) );
     } else {
       update_term_meta( $term_id, 'showcase-taxonomy-image-id', '' );
     }
   }
 
   /**
    * Enqueue styles and scripts
    * @since 1.0.0
    */
   public function add_script() {
     if( ! isset( $_GET['taxonomy'] ) || $_GET['taxonomy'] != 'skt_tours_category' ) {
       return;
     } ?>
     <script> jQuery(document).ready( function($) {
       _wpMediaViewsL10n.insertIntoPost = '<?php _e( "Insert", "showcase" ); ?>';
       function ct_media_upload(button_class) {
         var _custom_media = true, _orig_send_attachment = wp.media.editor.send.attachment;
         $('body').on('click', button_class, function(e) {
           var button_id = '#'+$(this).attr('id');
           var send_attachment_bkp = wp.media.editor.send.attachment;
           var button = $(button_id);
           _custom_media = true;
           wp.media.editor.send.attachment = function(props, attachment){
             if( _custom_media ) {
               $('#showcase-taxonomy-image-id').val(attachment.id);
               $('#category-image-wrapper').html('<img class="custom_media_image" src="" style="margin:0;padding:0;max-height:100px;float:none;" />');
               $( '#category-image-wrapper .custom_media_image' ).attr( 'src',attachment.url ).css( 'display','block' );
             } else {
               return _orig_send_attachment.apply( button_id, [props, attachment] );
             }
           }
           wp.media.editor.open(button); return false;
         });
       }
       ct_media_upload('.showcase_tax_media_button.button');
       $('body').on('click','.showcase_tax_media_remove',function(){
         $('#showcase-taxonomy-image-id').val('');
         $('#category-image-wrapper').html('<img class="custom_media_image" src="" style="margin:0;padding:0;max-height:100px;float:none;" />');
       });
       // Thanks: http://stackoverflow.com/questions/15281995/wordpress-create-category-ajax-response
       $(document).ajaxComplete(function(event, xhr, settings) {
         var queryStringArr = settings.data.split('&');
         if( $.inArray('action=add-tag', queryStringArr) !== -1 ){
           var xml = xhr.responseXML;
           $response = $(xml).find('term_id').text();
           if($response!=""){
             // Clear the thumb image
             $('#category-image-wrapper').html('');
           }
          }
        });
      });
    </script>
   <?php }
  }
$Showcase_skt_tours_category = new Showcase_skt_tours_category();
$Showcase_skt_tours_category->init(); }

//[ourtour-category-listing limit='8']
function bestseller_products_carousel_func( $atts ) {
   extract( shortcode_atts( array(
    'limit' => '6'
  ), $atts ) );
  
  ob_start();
  ?>      
  <?php 
  $image = "";
  $categories = get_categories( array('taxonomy' => 'skt_tours_category')); foreach ($categories as $category) { ?>
   <?php
   // Get the current category ID, e.g. if we're on a category archive page
   // $category = get_category( get_query_var( 'ourtour' ) );
   $cat_id = $category->cat_ID;
   // Get the image ID for the category
   $image_id = get_term_meta ( $cat_id, 'showcase-taxonomy-image-id', true );
   // Echo the image
   $image = wp_get_attachment_image ( $image_id, 'large' ); 
   ?>
   <div class="skt-tourcat-column">
      <div class="skt-tourcat-column-inner">
        <div class="skt-tourcat-column-image"> 
        <?php if($image == "") { ?>
        <img src="<?php echo get_template_directory_uri(); ?>/images/default-category-img.jpg"/>
        <?php } else { ?>
        <?php echo $image; ?>
        <?php } ?>
        </div>
        <div class="skt-tourcat-column-info"> 
        <a href="<?php echo esc_url( get_category_link( $category->term_id ) ); ?>" title="<?php echo $category->cat_name; ?>" class="skt-tourcat-column-overlay">
        <h3 class="skt-tourcat-column-overlay-title">
           <?php echo $category->cat_name; ?>
        </h3>
        </a>
        <a href="<?php echo esc_url( get_category_link( $category->term_id ) ); ?>" title="<?php echo $category->cat_name; ?>"><span class="skt-tourcat-column-catcount"><?php echo $category->count; ?> Tours Available </span></a>
        </div>
      </div>
    </div>        
  <?php } ?>
  <?php
  $output_string = ob_get_contents();
  ob_end_clean();
  return $output_string;
}
add_shortcode( 'ourtour-category-listing', 'bestseller_products_carousel_func' );
////

// Shortcode Our Tour
// [ourtour col='3' show='3' excerptlength='15' buttontext='Explore More']

function ourtour_func( $atts ) {
   extract( shortcode_atts( array(
		'col' => '',
		'show' => '',
		'excerptlength' => '',
		'buttontext' => '',
	), $atts ) );
	  extract( shortcode_atts( array( 'show' => $show,), $atts ) ); $ourtr = ''; wp_reset_query(); 

	$ourtr = '<div class="sectionrow tour-wrap">';
	$args = array( 'post_type' => 'skt_tours', 'posts_per_page' => $show, 'post__not_in' => get_option('sticky_posts'), 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	$n = 0;
	if ( have_posts() ) {
		while ( have_posts() ) { 
			$n++;
			the_post();
			$tourexcerpt = esc_html( get_post_meta( get_the_ID(), 'tourexcerpt', true ) );
			$tourdays = esc_html( get_post_meta( get_the_ID(), 'tourdays', true ) );
			$tourprice = esc_html( get_post_meta( get_the_ID(), 'tourprice', true ) );
			
			if( $col == 1 ){
				$ourtr .= '<div class="cols1';
			}elseif( $col == 2 ){
				$ourtr .= '<div class="cols2';
			}elseif( $col == 3 ){
				$ourtr .= '<div class="cols3';
			}elseif( $col == 4 ){
				$ourtr .= '<div class="cols4';
			}elseif( $col == 5 ){
				$ourtr .= '<div class="cols5';
			}
			$ourtr .= '">';
 
			$ourtr .= ' 
			<div class="tour-thumb">
			<a href="'.get_permalink().'" title="'.get_the_title().'">'.( (get_the_post_thumbnail( get_the_ID(), 'full') != '') ? get_the_post_thumbnail( get_the_ID(), 'full') : '<img src="'.get_template_directory_uri().'/images/team_thumb.jpg" />' ).'</a></div>';
                $ourtr .= '<div class="tour-infobox">';
				
				if( $tourdays != '' ){ $ourtr .= '<span class="tour-days">'.$tourdays.'</span>';}
				$ourtr .= '<h5><a href="'.get_permalink().'">'.get_the_title().'</a></h5>';
				
				if( $tourexcerpt != '' ){ $ourtr .= '<p>'.$tourexcerpt.'</p>';}
				else{
				$ourtr .= ' '.( ($excerptlength!='') ? '<p>'.wp_trim_words( get_the_content(), $excerptlength, '' ).'</p>' : '' ).'';
				}
					
				if( $tourprice != '' ){ $ourtr .= '<div class="tour-price"><span>from </span><h4>'.$tourprice.'</h4></div>';}
				$ourtr .= '<div class="exploremore"><a href="'.get_permalink().'">'.$buttontext.'</a></div>';
                    
                $ourtr .= '</div></div>';
		}
	}else{
		$ourtr .= 'Sorry, No Tour Found.';
	}
	wp_reset_query();
	$ourtr .= '</div>';
    return $ourtr;
}
add_shortcode( 'ourtour', 'ourtour_func' );


//custom post type for Our Service
function my_custom_post_service() {
	$labels = array(
		'name'               => __( 'Our Service', 'complete' ),
		'singular_name'      => __( 'Our Service', 'complete' ),
		'add_new'            => __( 'Add Service', 'complete' ),
		'add_new_item'       => __( 'Add New Service', 'complete' ),
		'edit_item'          => __( 'Edit Service', 'complete' ),
		'new_item'           => __( 'New Service', 'complete' ),
		'all_items'          => __( 'All Service', 'complete' ),
		'view_item'          => __( 'View Service', 'complete' ),
		'search_items'       => __( 'Search Service', 'complete' ),
		'not_found'          => __( 'No Service found', 'complete' ),
		'not_found_in_trash' => __( 'No Service found in the Trash', 'complete' ), 
		'parent_item_colon'  => '',
		'menu_name'          => 'Our Service'
	);
	$args = array(
		'labels'        => $labels,
		'description'   => 'Manage Service',
		'public'        => true,
		'menu_position' => null,
		'menu_icon'		=> 'dashicons-admin-generic',
		'supports'      => array( 'title', 'editor', 'thumbnail' ),
		'rewrite' => array('slug' => 'our-service'),
		'has_archive'   => true,
		'exclude_from_search' => true,
	);
	register_post_type( 'service', $args );
}
add_action( 'init', 'my_custom_post_service' );

// Shortcode Our Service Rotator
// [ourservice-rotator show='-1' excerptlength='24' readmoretext='Read More']

function ourservice_func( $atts ) {
    extract( shortcode_atts( array(
		'show' => '3',
		'excerptlength' => '24',
		'readmoretext'  => 'Read More',
	), $atts ) );
	  extract( shortcode_atts( array( 'show' => $show,), $atts ) );	
	
	$serviceoutput = '<div id="ourservice">
  <div class="ourservice">';
	wp_reset_query();
	 $args = array( 'post_type' => 'service', 'posts_per_page' => $show, 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	if ( have_posts() ) :
		while ( have_posts() ) : the_post();
		$serviceoutput .= '<div class="item">';
		if ( has_post_thumbnail() ){ 
		$serviceoutput .= '<a href="'.get_permalink().'" title="'.get_the_title().'"><div class="ser_thumb">'.( (get_the_post_thumbnail( get_the_ID(), 'thumbnail') != '') ? get_the_post_thumbnail( get_the_ID(), 'full') : '<img src="'.get_template_directory_uri().'/images/default-servicethumb.jpg">' ).'</div></a>'; 
		}
		$serviceoutput .= '
		        <div class="ser_info">
					<a href="'.get_permalink().'" title="'.get_the_title().'"><span class="ser_title">'.get_the_title().'</span></a>
					<p class="ser_p">'.wp_trim_words( get_the_content(), $excerptlength ).'</p>
				    <div class="readmorepost"><a href="'.get_permalink().'">'.$readmoretext.'</a></div>
				</div>
			</div>		  
			';
		endwhile;
		 $serviceoutput .= '</div></div>';
	else:
	  $serviceoutput = 'Services is empty!';			
	endif;  
	wp_reset_query();
	return $serviceoutput;
}
add_shortcode( 'ourservice-rotator', 'ourservice_func' );

// Shortcode Our Services
// [ourservices col="4" show="4"]

function ourservicebox_func( $atts ) {
   extract( shortcode_atts( array(
		'col' => '',
		'show' => '',
		'excerptlength' => '24',
		'readmoretext'  => 'Read More',
	), $atts ) );
	  extract( shortcode_atts( array( 'show' => $show,), $atts ) ); $serviceoutput = ''; wp_reset_query(); 

	$serviceoutput = '<div class="sectionrow service-box">';
	$args = array( 'post_type' => 'service', 'posts_per_page' => $show, 'post__not_in' => get_option('sticky_posts'), 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	$n = 0;
	if ( have_posts() ) {
		while ( have_posts() ) { 
			$n++;
			the_post();
			$marg_cls2 = ($n % 2) ? '' : 'no_margin_right';
			$marg_cls3 = ($n % 3) ? '' : 'no_margin_right';
			$marg_cls4 = ($n % 4) ? '' : 'no_margin_right';
			
			if( $col == 1 ){
				$serviceoutput .= '<div class="cols1 '.$marg_cls.'';
			}elseif( $col == 2 ){
				$serviceoutput .= '<div class="cols2 '.$marg_cls2.'';
			}elseif( $col == 3 ){
				$serviceoutput .= '<div class="cols3 '.$marg_cls3.'';
			}elseif( $col == 4 ){
				$serviceoutput .= '<div class="cols4 '.$marg_cls4.'';
			} 
				$serviceoutput .= '">';
			$serviceoutput .= '<div class="service_wrap"><div class="ser_thumb"><a href="'.get_permalink().'" title="'.get_the_title().'">'.( (get_the_post_thumbnail( get_the_ID(), 'thumbnail') != '') ? get_the_post_thumbnail( get_the_ID(), 'full') : '<img src="'.get_template_directory_uri().'/images/default-servicethumb.jpg">' );
	  			$serviceoutput .= '</a>'.'</div>';

			   $serviceoutput .= '<div class="ser_info">';
					$serviceoutput .= '
					<a href="'.get_permalink().'" title="'.get_the_title().'"><span class="ser_title">'.get_the_title().'</span></a>
					<p class="ser_p">'.wp_trim_words( get_the_content(), $excerptlength ).'</p>
				    <div class="ser_readmore"><a href="'.get_permalink().'">More</a></div>';
						
				$serviceoutput .= '</div></div></div>';
		}
	}else{
		$serviceoutput .= 'Sorry, No Service found.';
	}
	wp_reset_query();
	$serviceoutput .= '</div>';
    return $serviceoutput;
}
add_shortcode( 'ourservices', 'ourservicebox_func' );

// Shortcode Services

/* [service pattern="boxpattern-1" icon="image.jpg" title="Title" go="fa-angle-right" url="#"]Description[/service] */

// add shortcode for service box
function servicebox($atts, $content = null){
		extract( shortcode_atts(array(
			'pattern' => 'pattern',
			'icon'  => 'icon',
			'title'  => 'title',
			'go'  => 'go',
			'url' => 'url',
		), $atts));
		
		return '
			 <a href="'.$url.'"><div class="servicebox '.$pattern.'">
			 	<div class="serviceboxbg">
					<img src="'.$icon.'">
					<h3>'.$title.'</h3>
					<p>'.$content.'</p>
					<div class="sktgo"><i class="fa '.$go.'" aria-hidden="true"></i>
</div>
				</div>
			 </div></a>	
		';
}
add_shortcode('service','servicebox');

//[clear]
function clear_func() {
	$clr = '<div class="clear"></div>';
	return $clr;
}
add_shortcode( 'clear', 'clear_func' );


//[space height="20"]
function space_shortcode_func($atts ) {
 extract( shortcode_atts( array(
  'height' => '20',
 ), $atts ) );
 $sptr = '<div class="spacecode" style="height:'.$height.'px;"></div>';
 return $sptr;
}
add_shortcode( 'space', 'space_shortcode_func' );


//custom post type for Our photogallery
add_action("admin_init", "admin_init");
function admin_init(){
	add_meta_box("video_file_url-meta", "Video File URL", "video_file_url", "photogallery", "normal", "low"); 
}

function video_file_url () {
	global $post;  
	$custom     = get_post_custom($post->ID);  
	$video_file_url  = isset ( $custom["video_file_url"][0] ) ? $custom["video_file_url"][0] : '';  ?> 
	<style>
	.amount_input { margin:0; padding:6px; width:80%; }
	</style>
	<table width="100%"> 
		<tr><td width="110">Video File URL : </td><td colspan="2"><input class="amount_input" type="text" name="video_file_url"  value="<?php echo $video_file_url; ?>"  /></td></tr> 
		<tr><td></td><td><strong>YouTube video url:</strong></td><td>http://www.youtube.com/watch?v=qqXi8WmQ_WM</td></tr> 
		<tr><td></td><td width="120"><strong>Vimeo video url:</strong></td><td>http://vimeo.com/8245346</td></tr> 
	</table>
	<?php
}

add_action('save_post', 'save_details');
function save_details(){
	global $post; 
	if ( isset($_POST["video_file_url"]) ) {
		update_post_meta($post->ID, "video_file_url", $_POST["video_file_url"]);
	} 
}

//custom post type for Our photogallery
function my_custom_post_photogallery() {
	$labels = array(
		'name'               => __( 'Photo Gallery','complete' ),
		'singular_name'      => __( 'Photo Gallery','complete' ),
		'add_new'            => __( 'Add New','complete' ),
		'add_new_item'       => __( 'Add New Image / Video','complete' ),
		'edit_item'          => __( 'Edit Image/Video','complete' ),
		'new_item'           => __( 'New Image/Video','complete' ),
		'all_items'          => __( 'All Images/Videos','complete' ),
		'view_item'          => __( 'View Image/Video','complete' ),
		'search_items'       => __( 'Search Images/Videos','complete' ),
		'not_found'          => __( 'No images/videos found','complete' ),
		'not_found_in_trash' => __( 'No images/videos found in the Trash','complete' ), 
		'parent_item_colon'  => '',
		'menu_name'          => 'Photo Gallery'
	);
	$args = array(
		'labels'        => $labels,
		'description'   => 'Manage Photo Gallery',
		'public'        => true,
		'menu_icon'		=> 'dashicons-format-image',
		'supports'      => array( 'title', 'thumbnail' ),
		'has_archive'   => true,
	);
	register_post_type( 'photogallery', $args );
}
add_action( 'init', 'my_custom_post_photogallery' );


//  register gallery taxonomy
register_taxonomy( "gallerycategory", 
	array("photogallery"), 
	array(
		"hierarchical" => true, 
		"label" => "Gallery Category", 
		"singular_label" => "Photo Gallery", 
		"rewrite" => true
	)
);

add_action("manage_posts_custom_column",  "photogallery_custom_columns");
add_filter("manage_edit-photogallery_columns", "photogallery_edit_columns");
function photogallery_edit_columns($columns){
	$columns = array(
		"cb" => '<input type="checkbox" />',
		"title" => "Gallery Title",
		"pcategory" => "Gallery Category",
		"view" => "Image",
		"date" => "Date",
	);
	return $columns;
}
function photogallery_custom_columns($column){
	global $post;
	switch ($column) {
		case "pcategory":
			echo get_the_term_list($post->ID, 'gallerycategory', '', ', ','');
		break;
		case "view":
			the_post_thumbnail('thumbnail');
		break;
		case "date":

		break;
	}
}

//[photogallery filter="true"]
function photogallery_shortcode_func( $atts ) {
	extract( shortcode_atts( array(
		'show' => -1,
		'filter' => 'true'
	), $atts ) );
	$pfStr = '';

	$pfStr .= '<div class="portfolio-content">';
	if( $filter == 'true' ){
		$pfStr .= '<ul class="portfolio-categ filter"><li class="all active"><a href="#">'.esc_html__('ALL').'</a></li>';
		$categories = get_categories( array('taxonomy' => 'gallerycategory') );
		foreach ($categories as $category) {
			$pfStr .= '<li class="cat-item-'.$category->slug.'"><a href="#" title="'.$category->name.'">'.$category->name.'</a></li>';
		}
		$pfStr .= '</ul>';
	}

	$pfStr .= '<ul class="portfolio-area">';
	$j=0;
	query_posts('post_type=photogallery&posts_per_page='.$show); 
	if ( have_posts() ) : while ( have_posts() ) : the_post(); 
	$j++;
		$videoUrl = get_post_meta( get_the_ID(), 'video_file_url', true);
		$imgSrc = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full');
		$terms = wp_get_post_terms( get_the_ID(), 'gallerycategory', array("fields" => "all"));
		$slugAr = array();
		foreach( $terms as $tv ){
			$slugAr[] = $tv->slug;
		}
		if ( $imgSrc[0]!='' ) {
			$imgUrl = $imgSrc[0];
		}else{
			$imgUrl = get_template_directory_uri().'/images/gallery_thumb.jpg';
		}
		$pfStr .= '<li data-id="id-'.$j.'" data-type="cat-item-'.implode(' ', $slugAr).'" class="portfolio-item2">
 <a class="image-zoom" href="'.( ($videoUrl) ? $videoUrl : $imgSrc[0] ).'" rel="prettyPhoto[gallery]" title="'.get_the_title().'"><div class="image-block"><h4 class="image-block-title">'.get_the_title().'</h4><img src="'.$imgSrc[0].'" alt="'.get_the_title().'" title="'.get_the_title().'"/></div></a>
            </li>
			';
		unset( $slugAr );
	endwhile; else: 
		$pfStr .= '<p>Sorry, photo gallery is empty.</p>';
	endif; 
	wp_reset_query();
	$pfStr .= '</ul>';
	$pfStr .= '<div class="clear"></div></div>';
	return $pfStr;
}
add_shortcode( 'photogallery', 'photogallery_shortcode_func' );

/// Gallery By Category Id

//[gallery catslug="cat-slug"]
function gallery_shortcode_func( $atts ) {
	extract( shortcode_atts( array(
		'catslug' => '',
	), $atts ) );
	$pfStr = '';

	$pfStr .= '<div class="portfolio-content">';
	$pfStr .= '<ul class="portfolio-area">';
	$j=0;
	query_posts('post_type=photogallery&posts_per_page=-1&gallerycategory='.$catslug); 
	if ( have_posts() ) : while ( have_posts() ) : the_post(); 
	$j++;
		$videoUrl = get_post_meta( get_the_ID(), 'video_file_url', true);
		$imgSrc = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full');
		$terms = wp_get_post_terms( get_the_ID(), 'gallerycategory', array("fields" => "all"));
		$slugAr = array();
		foreach( $terms as $tv ){
			$slugAr[] = $tv->slug;
		}
		if ( $imgSrc[0]!='' ) {
			$imgUrl = $imgSrc[0];
		}else{
			$imgUrl = get_template_directory_uri().'/images/gallery_thumb.jpg';
		}
		$pfStr .= '<li data-id="id-'.$j.'" data-type="cat-item-'.implode(' ', $slugAr).'" class="portfolio-item2">
 <a class="image-zoom" href="'.( ($videoUrl) ? $videoUrl : $imgSrc[0] ).'" rel="prettyPhoto[gallery]" title="'.get_the_title().'"><div><span class="image-block"><img src="'.$imgSrc[0].'" alt="'.get_the_title().'" title="'.get_the_title().'"/></span></div></a>
            </li>
			';
		unset( $slugAr );
	endwhile; else: 
		$pfStr .= '<p>Sorry, photo gallery is empty.</p>';
	endif; 
	wp_reset_query();
	$pfStr .= '</ul>';
	$pfStr .= '<div class="clear"></div></div>';
	return $pfStr;
}
add_shortcode( 'gallery', 'gallery_shortcode_func' );
/// Gallery By Category Id

//[gallery-carousel]
// Photo Gallery Carousel
function carousel_gallery_shortcode_func( $atts ){
   extract( shortcode_atts( array(
		'show' => -1,
	), $atts ) );
	  extract( shortcode_atts( array( 'show' => $show,), $atts ) );	
	
$carsl = '<div class="galcarosel">';
	wp_reset_query();
	 $args = array( 'post_type' => 'photogallery', 'posts_per_page' => $show, 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	if ( have_posts() ) :
		while ( have_posts() ) : the_post();
		$caroimgSrc = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full');
		$carovideoUrl = get_post_meta( get_the_ID(), 'video_file_url', true);
					if ( $caroimgSrc[0]!='' ) {
			$imgUrl = $caroimgSrc[0];
		}else{
			$imgUrl = get_template_directory_uri().'/images/carousel-thumb.jpg';
		}
			$carsl .= '
		   <div class="galslide">
 				<a class="image-zoom" href="'.( ($carovideoUrl) ? $carovideoUrl : $caroimgSrc[0] ).'" rel="prettyPhoto[gallery]" title="'.get_the_title().'"><img src="'.$caroimgSrc[0].'" alt="'.get_the_title().'" title="'.get_the_title().'"/></a>
			</div>			  
			';
		endwhile;
		 $carsl .= '</div>';
	else:
	  $carsl = ' 
	  <div class="galcaroselno">Sorry, photo gallery is empty.</div>
	   ';			
	  endif;  
	wp_reset_query();
	return $carsl;
}
add_shortcode( 'gallery-carousel', 'carousel_gallery_shortcode_func' );

//[posts-style1 show='4' cat='1' excerptlength='24'] 
// Shortcode Post Block Style1

function post_style1_func( $atts ) {
	global $complete;
	global $authordata;
   extract( shortcode_atts( array(
		'show' => '3',
		'cat' => '1',
		'excerptlength' => '24',
		'readmoretext'  => 'Read More',
	), $atts ) );

	$lbposts = '<div class="post_style1_area">';
	$args = array( 'posts_per_page' => $show, 'cat' => $cat, 'post__not_in' => get_option('sticky_posts'), 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	
	if ( have_posts() ) {
		$n = 1;
		while ( have_posts() ) { 
			the_post();
			$marg_cls = ($n % 4) ? '' : 'no_margin_right';
			$marg_clr = ($n % 4) ? '' : '<div class="clear"></div>';
			$lbposts .= '<div class="post_block_style1 '.$marg_cls.'">'; 
			
			if ( has_post_thumbnail() ){ $lbposts .= '<div class="style1-post-thumb">'; }
			$lbposts .= '<div class="style1-post-thumb"><a href="'.get_permalink().'" title="'.get_permalink().'">'.( (get_the_post_thumbnail( get_the_ID(), 'thumbnail') != '') ? get_the_post_thumbnail( get_the_ID(), 'full') : '<img src="'.get_template_directory_uri().'/images/default-thumbnail.jpg">' ).'</a>';
			$lbposts .= '<div class="post_block_style2_meta">
                	<span><i class="fa fa-user"></i>By: '.get_the_author().' </span> <span><i class="fa fa-calendar" style="margin-left:10px;"></i>'.get_the_date('j M Y').'</span>';
            $lbposts .= '</div>	';			
			if ( has_post_thumbnail() ){
			$lbposts .= '</div>';
			}
			
				$lbposts .= '<div class="post_block_style1_info '.$marg_cls.'">';
				$lbposts .= '<h3><a href="'.get_permalink().'" title="'.get_the_title().'">'.get_the_title().'</a></h3>
				<p>'.wp_trim_words( get_the_content(), $excerptlength ).'</p>
				<div class="readmorepost"><a href="'.get_permalink().'">'.$readmoretext.'</a></div>
				</div></div>'.$marg_clr.'';
				$n++;
		}
	}else{
		$lbposts .= '<p>Sorry! There are no posts.</p>';
	}
	wp_reset_query();
	$lbposts .= '</div>';
    return $lbposts;
}
add_shortcode( 'posts-style1', 'post_style1_func' );

//[posts-style2 show='2' cat='1' excerptlength='24'] 
// Shortcode Post Block Style2

function post_style2_func( $atts ) {
	global $complete;
	global $authordata;
   extract( shortcode_atts( array(
		'show' => '2',
		'cat' => '1',
		'readmoretext'  => 'Read More',
	), $atts ) );

	$lbposts = '<div class="post_style2_area">';
	$args = array( 'posts_per_page' => $show, 'cat' => $cat, 'post__not_in' => get_option('sticky_posts'), 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	
	if ( have_posts() ) {
		$n = 1;
		while ( have_posts() ) { 
			the_post();
			$marg_cls = ($n % 3) ? '' : 'no_margin_right';
			$marg_clr = ($n % 4) ? '' : '<div class="clear"></div>';
			$lbposts .= '<div class="post_block_style2 '.$marg_cls.'">'; 
						if ( has_post_thumbnail() ){
			$lbposts .= '<div class="style2-post-thumb">';
			}
			$lbposts .= '<a href="'.get_permalink().'" title="'.get_the_title().'">'.( (get_the_post_thumbnail( get_the_ID(), 'thumbnail') != '') ? get_the_post_thumbnail( get_the_ID(), 'full') : '<img src="'.get_template_directory_uri().'/images/default-thumbnail.jpg">' ).'</a>'; if ( has_post_thumbnail() ){ 
			$lbposts .= '</div>'; } 
			$lbposts .= '
			<div class="post_info">
				<div class="post_block_style2_meta">
                	<span><i class="fa fa-clock-o"></i>'.get_the_date('j M Y').'</span> | <span><i class="fa fa-comment-o"></i>'.get_comments_number().' Comments</span>
            	</div>
				<h4><a href="'.get_permalink().'" title="'.get_the_title().'">'.get_the_title().'</a></h4>
				<div class="readmorepost"><a href="'.get_permalink().'">'.$readmoretext.'</a></div>
				</div></div>'.$marg_clr.'';
				$n++;
		}
	}else{
		$lbposts .= '<p>Sorry! There are no post.</p>';
	}
	wp_reset_query();
	$lbposts .= '</div>';
    return $lbposts;
}
add_shortcode( 'posts-style2', 'post_style2_func' );

// Post Style 3
//[posts-style3 show="12" cat="1" excerptlength="24"] 
// Shortcode Post Block Style3

function post_style3_func( $atts ) {
	global $complete;
	global $authordata;
   extract( shortcode_atts( array(
		'show' => '2',
		'cat' => '1',
		'excerptlength' => '24',
	), $atts ) );

	$lbposts = '<div class="post_style3_area">';
	$args = array( 'posts_per_page' => $show, 'cat' => $cat, 'post__not_in' => get_option('sticky_posts'), 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	
	if ( have_posts() ) {
		$n = 1;
		while ( have_posts() ) { 
			the_post();
			$marg_cls = ($n % 2) ? '' : 'no_margin_right';
			$marg_clr = ($n % 2) ? '' : '<div class="clear"></div>';
			$lbposts .= '<div class="post_block_style3 '.$marg_cls.'">'; 
			
			if(has_post_thumbnail() ){
			$lbposts .= '<div class="style3thumb"><a href="'.get_permalink().'" title="'.get_the_title().'">'.( (get_the_post_thumbnail( get_the_ID(), 'thumbnail') != '') ? get_the_post_thumbnail( get_the_ID(), 'full') : '<img src="'.get_template_directory_uri().'/images/default-thumbnail.jpg">' ).'</a></div>'; 
			}
					if(has_post_thumbnail() ){
					$lbposts .= '<div class="style3info">'; 
					}
					else{
					$lbposts .= '<div class="style3infonothumb">'; 	
					}
					$lbposts .= '<h3>'.get_the_title().'</h3>'; 
					$lbposts .= '<div class="shortdesc">'.wp_trim_words( get_the_content(), $excerptlength ).'</div>';
					$lbposts .= '<div class="shortmore"><a href="'.get_permalink().'">'.$complete['recentpost_block_button'].'</a></div>';
					$lbposts .= '</div></div>'.$marg_clr.'';
				$n++;
		}
	}else{
		$lbposts .= '<p>Sorry! There are no post.</p>';
	}
	wp_reset_query();
	$lbposts .= '</div>';
    return $lbposts;
}
add_shortcode( 'posts-style3', 'post_style3_func' );
// Post Style 3
 
 

//[posts-timeline show="4" cat="1" excerptlength="24"] 
// Shortcode Post Time Line

function post_timeline_func( $atts ) {
	global $complete;
	global $authordata;
   extract( shortcode_atts( array(
   		'show' => '4',
		'cat' => '1',
		'excerptlength' => '24',
	), $atts ) );

	$tmlposts = '<div class="timeline-container">
  <div class="timeline-row">
    <ul class="timeline-both-side">';
	$args = array( 'posts_per_page' => $show, 'cat' => $cat, 'post__not_in' => get_option('sticky_posts'), 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	
	if ( have_posts() ) {
		$n = 1;
		while ( have_posts() ) { 
			the_post();
			$marg_cls = ($n % 2) ? '' : 'opposite-side';
			$tmlposts .= '<li class="'.$marg_cls.'">'; 
			$tmlposts .= '<div class="border-line"></div><div class="timeline-description">
			<div class="timeleft"><a href="'.get_permalink().'" title="'.get_the_title().'">'.( (get_the_post_thumbnail( get_the_ID(), 'thumbnail') != '') ? get_the_post_thumbnail( get_the_ID(), 'full') : '<img src="'.get_template_directory_uri().'/images/default-thumbnail.jpg">' ).'</a></div>'; 
			if ( has_post_thumbnail() ){$tmlposts .= '<div class="timeright">'; }else {$tmlposts .= '<div class="timerightfull">';}
			$tmlposts .= '<h3><a href="'.get_permalink().'" title="'.get_the_title().'">'.get_the_title().'</a></h3><div class="post_block_style1_meta">
                	<span><a href="'.get_author_posts_url( $authordata->ID, $authordata->user_nicename ).'"><i class="fa fa-user fa-lg"></i> '.get_the_author().'</a></span><span><i class="fa fa-calendar"></i>
'.get_the_date('F j, Y').'</span>
                </div><p>'.wp_trim_words( get_the_content(), $excerptlength ).'</p><a class="sktmore" href="'.get_permalink().'">'.$complete['recentpost_block_button'].'</a> </div>
			</div></li> ';
				$n++;
		}
	}else{
		$tmlposts .= '<p>Sorry! There are no posts.</p>';
	}
	wp_reset_query();
	$tmlposts .= '</ul>
  </div>
</div>';
    return $tmlposts;
}
add_shortcode( 'posts-timeline', 'post_timeline_func' );

//[posts-grid show="4" cat="1" excerptlength="24"] 
// Shortcode Post Grid

function post_grid_func( $atts ) {
	global $complete;
	global $authordata;
   extract( shortcode_atts( array(
   		'show' => '4',
		'cat' => '1',   
		'excerptlength' => '24',
	), $atts ) );
	
	$gridposts = '<div class="gridwrapper">
<div class="masonry">';
	$args = array( 'posts_per_page' => $show, 'cat' => $cat, 'post__not_in' => get_option('sticky_posts'), 'orderby' => 'date', 'order' => 'desc' );
	query_posts( $args );
	
	if ( have_posts() ) {
		$n = 1;
		while ( have_posts() ) { 
			the_post();
			$gridposts .= '<div class="griditem"><a href="'.get_permalink().'" title="'.get_the_title().'">'.( (get_the_post_thumbnail( get_the_ID(), 'thumbnail') != '') ? get_the_post_thumbnail( get_the_ID(), 'full') : '' ).'</a>
<h3><a href="'.get_permalink().'" title="'.get_the_title().'">'.get_the_title().'</a></h3>
<div class="post_block_style1_meta">
                	<span><a href="'.get_author_posts_url( $authordata->ID, $authordata->user_nicename ).'"><i class="fa fa-user fa-lg"></i> '.get_the_author().'</a></span><span><i class="fa fa-calendar"></i>
'.get_the_date('F j, Y').'</span>
                </div><p>'.wp_trim_words( get_the_content(), $excerptlength ).'</p><a class="sktmore" href="'.get_permalink().'">'.$complete['recentpost_block_button'].'</a></div>'; 
				$n++;
		}
	}else{
		$gridposts .= '<p>Sorry! There are no posts.</p>';
	}
	wp_reset_query();
	$gridposts .= '</div></div>';
    return $gridposts;
}
add_shortcode( 'posts-grid', 'post_grid_func' );

// [skill title="HTML" percent="80" bgcolor="#ff7400"]
// add shortcode for skills
function skills_func($skill_var){
	extract( shortcode_atts(array(
		'title' 	=> 'title',
		'percent'	=> 'percent',
		'bgcolor'	=> 'bgcolor',
	), $skill_var));
	
	return '<div class="skillbar clearfix " data-percent="'.$percent.'%">
			<div class="skillbar-title"><span>'.$title.'</span>'.$percent.'%</div>
			<div class="skill-bg"><div class="skillbar-bar" style="background:'.$bgcolor.'"></div></div>
			</div>';
}

add_shortcode('skill','skills_func');

// Shortcode Client
/*[client url="#" image="image"]*/
function clientbox($atts){
		extract( shortcode_atts(array(
			'url' => 'url',
			'image' => 'image'
		), $atts));
		
		return '
                <div class="clientbox">
                    <a href="'.$url.'" target="_blank"><img src="'.$image.'"/></a>
                </div>
		';
}
add_shortcode('client','clientbox');

// Shortcode Box Thumb
/*[boxthumb name="name" url="#" image="image" target="blank"]*/
function thumbbox($atts){
		extract( shortcode_atts(array(
			'url' => 'url',
			'image' => 'image',
			'target' => 'target',
			'name' => 'name'
		), $atts));
		
		return '
				<div class="thumb">
					<div class="boxthumb">
						<a href="'.$url.'" target="_'.$target.'"><img src="'.$image.'"/></a>
					</div>
					<div class="thmbname">'.$name.'</div>
				</div>
		';
}
add_shortcode('boxthumb','thumbbox');

// Social Icon Shortcodes
/*[social_area]
    [social icon="facebook" link="#"]
    [social icon="twitter" link="#"]
    [social icon="linkedin" link="#"]
    [social icon="pinterest" link="#"]
[/social_area]*/
function complete_social_area($atts,$content = null){
  return '<div class="social-icons">'.do_shortcode($content).'</div>';
 }
add_shortcode('social_area','complete_social_area');

function complete_social($atts){
 extract(shortcode_atts(array(
  'icon' => '',
  'link' => ''
 ),$atts));
  return '<a href="'.$link.'" target="_blank" class="fa fa-'.$icon.' fa-1x" title="'.$icon.'"></a>';
 }
add_shortcode('social','complete_social');

// Footer Posts

/*[footerposts show="3"]*/
function footerpost_func( $atts ){
	global $post;
   extract( shortcode_atts( array(
		'show' => '',
	), $atts ) );
	$postoutput = '';
	wp_reset_query();
	query_posts(  array( 'posts_per_page'=>$show, 'post__not_in' => get_option('sticky_posts') )  );
	$postoutput .='<div class="footer-blog-posts">
            	<ul>';
	if ( have_posts() ) :
		while ( have_posts() ) : the_post();
 			if ( has_post_thumbnail()) {
				$large_image_url = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), 'footerthumb' );
				$imgUrl = '<img src="'.$large_image_url[0].'"/>';
			}
			else
			{ 
				$imgUrl = '<img style="display:none;" src=""/>';
			}
			$postoutput .= '<li><a href="'.get_the_permalink().'">'.get_the_title().'</a></li>';
		endwhile;
	endif;
	wp_reset_query();
	$postoutput .= '</ul></div>';
	return $postoutput;
}
add_shortcode( 'footerposts', 'footerpost_func' );	

// Shortcode Flip Box
/*[flipbox fliptype="fliptype" frontimage="frontimage" fronttitle="fronttitle" frontdescription="frontdescription" backtitle="backtitle" backdescription="backdescription" backurl="backurl" backbutton="backbutton"]*/

function flip($atts){
		extract( shortcode_atts(array(
			'fliptype' => 'fliptype',
			'frontimage' => 'frontimage',
			'fronttitle' => 'fronttitle',
			'frontdescription' => 'frontdescription',
			'backtitle' => 'backtitle',
			'backdescription' => 'backdescription',
			'backurl' => 'backurl',
			'backbutton' => 'backbutton',
		), $atts));
		
		return '
		<div class="flipcard '.$fliptype.'">
    <div class="front">
      	<div class="frontimage"><img src="'.$frontimage.'"/></div>
        <h3>'.$fronttitle.'</h3>
        <p>'.$frontdescription.'</p>
    </div>
    <div class="back">
	  <h3>'.$backtitle.'</h3>
      <p style="margin-bottom:20px;">'.$backdescription.'</p>
	  <a style="color:#FFF;" href="'.$backurl.'" class="sktmore"> '.$backbutton.' </a>
    </div>
</div>';

}
add_shortcode('flipbox','flip');

// Shortcode Divider
/*[divider style="divider1"]*/

function dividerstyle($atts){
		extract( shortcode_atts(array(
			'style' => 'style',
		), $atts));
		
		return '
		<div class="'.$style.'"><span></span></div>
		';

}
add_shortcode('divider','dividerstyle');

// Shortcode Heading Divider
/*[headingdivider text="text"]*/

function dividerstyleheading($atts){
		extract( shortcode_atts(array(
			'text' => 'text',
		), $atts));
		
		return '
		 <div class="fusion-title"><h3>'.$text.'</h3><div class="title-sep-container"><div class="title-sep sep-double"></div></div></div>
		';

}
add_shortcode('headingdivider','dividerstyleheading');

// Shortcode Heading Seperator
/*[headingseperator text="text"]*/

function headingseperatorstyle($atts){
		extract( shortcode_atts(array(
			'text' => 'text',
		), $atts));
		
		return '
		 <div class="headingseperator"><h3>'.$text.'</h3></div>
		';

}
add_shortcode('headingseperator','headingseperatorstyle');

// Shortcode Center Title Seperator
/*[centertitle text="text" titlecolor="#ffffff" seperatorcolor="#ffffff"]*/

function titlesep($atts){
		extract( shortcode_atts(array(
			'text' => 'text',
			'titlecolor' => 'seperatorcolor',
			'seperatorcolor' => 'seperatorcolor',
		), $atts));
		
		return '
		<div class="center-title"><h2 style="color:'.$titlecolor.'">'.$text.'</h2><span style="border-bottom-color:'.$seperatorcolor.'"></span></div>
		';

}
add_shortcode('centertitle','titlesep');

// Shortcode Promobox1
/* [promobox1 bgcolor="#f7f7f7" topbordercolor="#e64d43" otherbordercolor="#e8e6e6"]Description[/promobox1] */

function promo1($atts, $content = null){
		extract( shortcode_atts(array(
			'bgcolor'  => 'bgcolor',
			'topbordercolor'  => 'topbordercolor',
			'otherbordercolor'  => 'otherbordercolor',
		), $atts));
		
		return '
			 <div class="promo1" style="background-color:'.$bgcolor.'; border-color: '.$topbordercolor.' '.$otherbordercolor.' '.$otherbordercolor.';">
             	'.$content.'
             </div>	
		';
}
add_shortcode('promobox1','promo1');

// Shortcode Promobox2
/* [promobox2 bgcolor="#f7f7f7" leftbordercolor="#e64d43" button="Hello Text" url="#"]Description[/promobox2] */

function promo2($atts, $content = null){
		extract( shortcode_atts(array(
			'bgcolor'  => 'bgcolor',
			'leftbordercolor'  => 'leftbordercolor',
			'button'  => 'button',
			'url'  => 'url',
		), $atts));
		
		return '
			 <div class="promo2" style="background-color:'.$bgcolor.'; border-left-color:'.$leftbordercolor.';">
             	<div class="promo-left">
             	'.$content.'
                </div>
                <div class="promo-right">
                <div class="sktmore"><a href="'.$url.'">'.$button.'</a></div>
                </div>
                <div class="clear"></div>
             </div>	
		';
}
add_shortcode('promobox2','promo2');

// Shortcode Promobox3
/* [promobox3 bgcolor="#f7f7f7" bottombordercolor="#e64d43" button="Hello Text" url="#"]Description[/promobox3] */

function promo3($atts, $content = null){
		extract( shortcode_atts(array(
			'bgcolor'  => 'bgcolor',
			'bottombordercolor'  => 'bottombordercolor',
			'button'  => 'button',
			'url'  => 'url',
		), $atts));
		
		return '
			 <div class="promo3" style="background-color:'.$bgcolor.'; border-bottom-color:'.$bottombordercolor.';">
             	'.$content.'
                <div class="sktmore"><a href="'.$url.'">'.$button.'</a></div>
             </div>	
		';
}
add_shortcode('promobox3','promo3');

// Shortcode Promobox4
/* [promobox4 bgcolor="#f7f7f7" bordercolor="#e64d43"]Description[/promobox4] */

function promo4($atts, $content = null){
		extract( shortcode_atts(array(
			'bgcolor'  => 'bgcolor',
			'bordercolor'  => 'bordercolor',
		), $atts));
		
		return '
			<div class="promo4" style="background-color:'.$bgcolor.'; border-color:'.$bordercolor.';">
            	'.$content.'
             </div>	
		';
}
add_shortcode('promobox4','promo4');

// Shortcode Promobox5
/* [promobox5 bgcolor="#f7f7f7" button="Hello Text" url="#"]Description[/promobox5] */

function promo5($atts, $content = null){
		extract( shortcode_atts(array(
			'bgcolor'  => 'bgcolor',
			'button'  => 'button',
			'url'  => 'url',
		), $atts));
		
		return '
			 <div class="promo5" style="background-color:'.$bgcolor.';">
             	'.$content.'
                <div class="sktmore"><a href="'.$url.'">'.$button.'</a></div>
             </div>	
		';
}
add_shortcode('promobox5','promo5');


// Shortcode Cols
/* [columns size="1"][/columns] */
function cols($atts, $content = null){
		extract( shortcode_atts(array(
			'size'  => 'size',
		), $atts));
		
		return '
			<div class="skt-columns-'.$size.'">'.do_shortcode($content).'</div>  	
		';
}
add_shortcode('columns','cols');

// Shortcode Features Left
/*[featuresleft url="#" title="title" description="description" ordernumber="ordernumber"]*/
function featuresboxleft($atts){
		extract( shortcode_atts(array(
			'url' => 'url',
			'title' => 'title',
			'description' => 'description',
			'ordernumber' => 'ordernumber'
		), $atts));
		
		return '
				<div class="left-fitbox">
				<a href="'.$url.'">
				<div class="left-fitleft">
					<div class="left-fit-title"><h3>'.$title.'</h3></div>
					<div class="left-fit-desc">'.$description.'</div>
				</div>
				<div class="left-fitright">'.$ordernumber.'</div>
				</a>
				</div>
				<div class="clear"></div>
		';
}
add_shortcode('featuresleft','featuresboxleft');

// Shortcode Thumb Box
/*[featurethumb url="#" image="image"]*/
function thumbnailbox($atts){
		extract( shortcode_atts(array(
			'url' => 'url',
			'image' => 'image'
		), $atts));
		
		return '
                <div class="featurethumb">
                    <a href="'.$url.'"><img src="'.$image.'"/></a>
                </div>
		';
}
add_shortcode('featurethumb','thumbnailbox');

// Shortcode Features Right
/*[featuresright url="#" title="title" description="description" ordernumber="ordernumber"]*/
function featuresboxright($atts){
		extract( shortcode_atts(array(
			'url' => 'url',
			'title' => 'title',
			'description' => 'description',
			'ordernumber' => 'ordernumber'
		), $atts));
		
		return '
				<div class="right-fitbox">
				<a href="'.$url.'">
				<div class="right-fitleft">'.$ordernumber.'</div>
				<div class="right-fitright">
				<div class="right-fit-title"><h3>'.$title.'</h3></div>
				<div class="right-fit-desc">'.$description.'</div></div>
				</a>
				</div>
				<div class="clear"></div>
		';
}
add_shortcode('featuresright','featuresboxright');

// Shortcode Blocks

/* [blocks icon="image.jpg" title="Title" readmoretext="Read More" url="#"]Description[/blocks] */

// add shortcode for blocks
function blocksbox($atts, $content = null){
		extract( shortcode_atts(array(
			'icon'  => 'icon',
			'title'  => 'title',
			'readmoretext'  => 'readmoretext',
			'url' => 'url',
		), $atts));
		
		return '
			 <div class="blocksbox">
							<div class="blockthumb"><img src="'.$icon.'" /></div>
							<div class="blocktitle">
								<h3>'.$title.'</h3>
							</div>
							<div class="blockdesc">'.$content.'</div>
							<div class="blockmore"><a href="'.$url.'">'.$readmoretext.'</a></div>
						</div>
		';
}
add_shortcode('blocks','blocksbox');

// Shortcode Square Box
/*[squarebox image="image" title="title" url="#" target="blank"]*/
function squareboxarea($atts){
		extract( shortcode_atts(array(
			'image' => 'image',
			'title' => 'title',
			'url' => 'url',
			'target' => 'target'
		), $atts));
		
		
		return '
				<a href="'.$url.'">
					<div class="squarebox">
					<div class="squareicon"><img src="'.$image.'" /></div>
					<div class="squaretitle">'.$title.'</div>
					</div>		
				 </a>
		';
}
add_shortcode('squarebox','squareboxarea');

// Shortcode Perfect Box
/*[perfectbox image="image" title="title" description="description" url="#" target="blank"]*/
function perfectboxarea($atts){
		extract( shortcode_atts(array(
			'image' => 'image',
			'title' => 'title',
			'description' => 'description',
			'url' => 'url',
			'target' => 'target'
		), $atts));
		
		
		return '
			 <div class="perfectbox">
						<a href="'.$url.'" target="_'.$target.'"><div class="perfectborder">
							 <div class="perf-thumb"><img src="'.$image.'"/></div>
							 <div class="perf-title"><h3>'.$title.'</h3></div>
							 <div class="perf-description">'.$description.'</div>	
						</div></a>
			 </div>
		';
}
add_shortcode('perfectbox','perfectboxarea');

// Shortcode Block Box
/*[blockbox url="url" image="image" title="title" titlecolor="titlecolor" target="self"]*/
function blockboxset($atts){
		extract( shortcode_atts(array(
		'url' => 'url',
		'target' => 'target',
		'titlecolor' => 'titlecolor',
		'image' => 'image',
		'title' => 'title',
		), $atts));	
		
		return '
			<div class="blockbox">
				<a href="'.$url.'" target="_'.$target.'">
					<div class="infoblockthumb"><img src="'.$image.'" /></div>
					<div class="infoblocktitle"><h4 style="color:'.$titlecolor.';">'.$title.'</h4></div>
				</a>
			</div>
		';
}
add_shortcode('blockbox','blockboxset');

// Footer Menu
/*[footermenu]*/
function foot_menu($atts, $content = null) {
	extract(shortcode_atts(array(  
		'menu'            => '', 
		'container'       => 'div', 
		'container_class' => '', 
		'container_id'    => '', 
		'menu_class'      => 'footmenu', 
		'menu_id'         => '',
		'echo'            => true,
		'fallback_cb'     => 'wp_page_menu',
		'before'          => '',
		'after'           => '',
		'link_before'     => '',
		'link_after'      => '',
		'depth'           => 1,
		'walker'          => '',
		'theme_location'  => 'footer'), 
		$atts));
 
 
	return wp_nav_menu( array( 
		'menu'            => $menu, 
		'container'       => $container, 
		'container_class' => $container_class, 
		'container_id'    => $container_id, 
		'menu_class'      => $menu_class, 
		'menu_id'         => $menu_id,
		'echo'            => false,
		'fallback_cb'     => $fallback_cb,
		'before'          => $before,
		'after'           => $after,
		'link_before'     => $link_before,
		'link_after'      => $link_after,
		'depth'           => $depth,
		'walker'          => $walker,
		'theme_location'  => $theme_location));
}
//Create the shortcode
add_shortcode("footermenu", "foot_menu");


function home_posts_func( $atts ) {
  global $complete;
  global $authordata;
   extract( shortcode_atts( array(
    'limit' => '3',
    'category' => '',
  ), $atts ) );
  
  ob_start();
  
  ?>
    
  <div class="skt-home-posts-row">
	<?php $args = array( 'posts_per_page' => $limit, 'category_name' => $category );
	query_posts( $args );
	
	if ( have_posts() ) {
	while ( have_posts() ) { the_post();
	?>
	<div class="skt-home-posts-column">
    	<div class="skt-home-posts-inner">
        	<div class="skt-home-posts-thumb">
				<?php if(has_post_thumbnail() ) { ?>
                    <a class="skt-home-posts-overlay" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_post_thumbnail( get_the_ID(), 'full' ); ?></a>
                <?php } else { ?>
                    <a class="skt-home-posts-overlay" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><img src="<?php echo get_template_directory_uri(); ?>/images/default-post-img.jpg"></a>
                <?php } ?>
			</div>
            <div class="skt-home-posts-content">
            	<span class="skt-home-posts-date"><i class="fa fa-user" aria-hidden="true"></i><?php the_author(); ?> <i class="fa fa-calendar" aria-hidden="true" style="margin-left: 20px;"></i><?php the_time('F d, Y'); ?></span>
            	<h3 class="skt-home-posts-title"><a class="skt-home-posts-overlay" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a></h3>
            </div>
        </div>
     </div>
      <?php } } else { ?><p>Sorry! There are no post.</p> <?php  } ?>
  
  <?php wp_reset_query(); ?>
  
  </div>

  <?php
  $output_string = ob_get_contents();
  ob_end_clean();
  return $output_string;
  
}
add_shortcode( 'home-posts', 'home_posts_func' );

// Working Hours
/*[working-hours day="Monday - Friday" time="10.00am - 8.00pm" daycolor="#ffffff" timecolor="#e64d43" bordercolor="#292d3a"]*/
function working_hours_func($atts){
		extract( shortcode_atts(array(
		'day' => 'day',
		'time' => 'time',
		'daycolor' => '#ffffff',
		'timecolor' => '#e64d43',
		'bordercolor' => '#292d3a',
		), $atts));	
		
		return '
			<div class="skt-working-hours" style="border-color:'.$bordercolor.';">
				<span style="color:'.$daycolor.';" class="skt-working-day">'.$day.'</span>
				<span style="color:'.$timecolor.';" class="skt-working-time">'.$time.'</span>
			</div>
		';
}
add_shortcode('working-hours','working_hours_func');


// add shortcode for day and timing 
function timingcal($skt_var){
		extract( shortcode_atts(array(
			'day' => 'day',
			'hours' => 'hours',
			'highlight' => '',
		), $skt_var));
		
		return '<div class="timingbox">
				<div class="openingday"><p>'.$day.'</p></div>
				<div class="openingtime"><p class="'.$highlight.'">'.$hours.'</p></div>
				<div class="clear"></div>
				</div>';
}
add_shortcode('timing','timingcal');


// [searchform]
/* Search Box */
add_shortcode('searchform', 'search_form'); 
function search_form() {
    $url = get_site_url();
    $form = '<form role="search" method="get" class="searchbox" action="'.$url.'">		
	<input type="search" class="searchbox-input" placeholder="Search" value="" name="s" onkeyup="buttonUp();">
	<input type="submit" class="" value="">
     <i class="fa fa-search"></i>
</form>';
    return $form;
}
/* Search Box */


// [searchadventure]
/* Search Box */
add_shortcode('searchadventure', 'search_adventure'); 
function search_adventure() {
    $advurl = get_site_url();
    $advform = '<form role="search" method="get" class="adventuresearchbox" action="'.$advurl.'/tour-search-results">  
  <div class="formcontainer">
    <div class="form-input"><i class="fa-map-marker"></i><input type="text" placeholder="Adventure Type" name="adventure_type"></div>
    <div class="form-input"><i class="fa-map-marker"></i>';
    $advform .= '<select name="destinations" required>';
    $terms = get_terms( array(
      'taxonomy' => 'skt_tours_category',
      'hide_empty' => false,
  ) );
  $advform .= '<option value="">Select Destinations</option>';
    foreach ($terms as $term) {
      $advform .= '<option value="'.$term->slug.'">'.$term->slug.'</option>';
  }
  $advform .= '</select>';
    $advform .= '</div>
    <div class="form-input">
    <i class="fa-money"></i>
    <select name="price">
  <option>Price</option>
  <option value="500">300 - 500</option>
    <option value="800">501 - 800</option>
    <option value="1000">801 - 1000</option>
  </select>
  </div>
    <div class="form-input">
    <i class="fa-clock"></i>
    <select  name="duration">
  <option value="">Duration</option>
  <option value="10">05 Days - 10 Days</option>
  <option value="15">11 Days - 15 Days</option>
  <option value="20">16 Days - 20 Days</option>
  </select>
  </div>
    <p class="guidecheck">
    <input type="checkbox">
    <label> Do you need a Guide?</label>
    </p>
    <input type="hidden" name="mode" value="searchadventure">
    <button type="submit" class="">Search Now!</button>
  </div>
</form>';
    return $advform;
}

/* New Product  */
//[newproduct filter="true" show="8" offersale="SALE!" buttonname="ADD TO CART"]
if ( class_exists( 'WooCommerce' ) )  {
function newproduct_shortcode_func( $atts ) {
	extract( shortcode_atts( array(
		'show' => -1,
		'filter' => 'false',
		'offersale' => '',
		'buttonname' => '',
		'excerptlength' => '9',
	), $atts ) );
	$newproductStr = '';

	$newproductStr .= '<div class="newproducts">';
	if( $filter == 'true' ){
		$newproductStr .= '<div class="newproductfilter"><ul class="clean" id="filterprod"><li class="current"><a href="javascript:void(0)">All</a></li>';
		$categories = get_categories( array('taxonomy' => 'product_cat') );
		foreach ($categories as $category) {
			$newproductStr .= '<li><a href="javascript:void(0)">'.$category->name.'</a></li>';
		}
		$newproductStr .= '</ul></div>';
	}
	$newproductStr .= '<div class="newproductgallery"><ul class="clean" id="portfolioprod">';
	$j=0;
	query_posts(  array('post_type' => 'product' , 'posts_per_page'=>$show,)  );
	if ( have_posts() ) : while ( have_posts() ) : the_post(); 
	global $post, $product;
	$j++;
		$imgSrc = wp_get_attachment_image_src( get_post_thumbnail_id(), array( 250, 325 ));
		$terms = wp_get_post_terms( get_the_ID(), 'product_cat', array("fields" => "all"));
		$productsale = $product->is_on_sale();
 		$slugAr = array();
		foreach( $terms as $tv ){
			$slugAr[] = $tv->slug;
		}
		if ( $imgSrc[0]!='' ) {
			$imgUrl = $imgSrc[0];
			
		}else{
			$imgUrl = get_template_directory_uri().'/images/placeholder.png';
		}
		$newproductStr .= '<li class="'.implode(' ', $slugAr).'" '.( ($j%4==0) ? 'style="margin-right:0"' : '' ).'>
				'.(($productsale!='') ? '<span class="onsale">'.$offersale.'</span>' : '' ) .'
		<div class="product-button">
		  <img src="'.$imgUrl.'"/> 
		  <div class="view-all-btn"><a href="'.$product->add_to_cart_url().'">'.$buttonname.'</a></div>
		  <div class="proinfo">
		     <a href="'.get_the_permalink().'"><h5>'.get_the_title().'</h5></a>
		     <div class="newproprice">'.$product->get_price_html().'</div>
		  </div>
		</div>
		</li>';
		unset( $slugAr );
		
	endwhile; else: 
		$newproductStr .= '<p>Sorry, Our Product is empty.</p>';
	endif; 
	wp_reset_query();
	$newproductStr .= '</ul></div>';
	$newproductStr .= '<div class="clear"></div></div>';
	return $newproductStr;
}
add_shortcode( 'newproduct', 'newproduct_shortcode_func' ); }

// Services Sidebar Menu
/*[sidebar-menu name='Services Sidebar']*/
function sidebar_menu($atts, $content = null) {
	extract(shortcode_atts(array(  
		'menu'            => '', 
		'container'       => 'div', 
		'container_class' => '', 
		'container_id'    => '', 
		'menu_class'      => 'sidebar-menu', 
		'menu_id'         => '',
		'echo'            => true,
		'fallback_cb'     => 'wp_page_menu',
		'before'          => '',
		'after'           => '',
		'link_before'     => '',
		'link_after'      => '',
		'depth'           => 1,
		'walker'          => '',
		'theme_location'  => 'footer'), 
		$atts)); 
 
	return wp_nav_menu( array( 
		'menu'            => $menu, 
		'container'       => $container, 
		'container_class' => $container_class, 
		'container_id'    => $container_id, 
		'menu_class'      => $menu_class, 
		'menu_id'         => $menu_id,
		'echo'            => false,
		'fallback_cb'     => $fallback_cb,
		'before'          => $before,
		'after'           => $after,
		'link_before'     => $link_before,
		'link_after'      => $link_after,
		'depth'           => $depth,
		'walker'          => $walker,
		'theme_location'  => $theme_location));
}
//Create the shortcode
add_shortcode("sidebar-menu", "sidebar_menu");